@@ -352,8 +352,6 @@ class Model:
         tables = {}
         for name in self.variablenames:
             if 'tbl' in name:
-                row = self.variable(name).row
-                print(self.variable(name).row)
                 positions.update({name:self.variable(name).row})
 
         for name in self.variablenames:
@@ -369,9 +367,8 @@ class Model:
             tables.update({s:key})
         result = []
         for key in tables:
-            p = table.split(':')[0]
-            n = table.split(':')[1]
-            result.update([p,n])
+            print(key, tables[key])
+            result.append([int(key.split(':')[0]),int(key.split(':')[1])])
         return result
 
     def import_data(self, data):
